import yuko
import pytest


# pytest parametrize
@pytest.mark.parametrize(
    "email, expected",
    [
        ("email", False),
        ("example@example.com", True),
        ("example@example", False),
        ("email@here.com", True),
        ("weirder-email@here.and.there.com", True),
        ("email@127.local.home.arpa", True),
        ("example@valid-----hyphens.com", True),
        ("example@valid-with-hyphens.com", True),
    ],
)
def test_email(email: str, expected: bool):
    assert yuko.email(email) == expected



from yuko import yuko  # type: ignore[attr-defined]
from yuko.yuko import *  # type: ignore[attr-defined] # noqa: F401, F403
import importlib.metadata as importlib_metadata

try:
    # This will read version from pyproject.toml
    __version__ = importlib_metadata.version(__package__ or __name__)
except importlib_metadata.PackageNotFoundError:
    __version__ = "development"


__doc__ = yuko.__doc__
if hasattr(yuko, "__all__"):
    __all__ = yuko.__all__



import yuko
import pytest


# pytest parametrize
@pytest.mark.parametrize(
    "url, expected",
    [
        ("invalidurl", False),
        ("http://example.com", True),
        ("https://example.com", True),
        ("http://example.com/", True),
        ("http://example.com/path", True),
        ("http://example.com/path/", True),
        ("ftp://example.com", True),
        ("http://", False),  # Invalid URL example
        ("https://www.example&.com", False),  # Invalid URL example
        ("https://www.example.com/path with spaces", False),  # Invalid URL example
    ],
)
def test_url(url: str, expected: bool):
    assert yuko.url(url) == expected



import pytest
import yuko


# pytest parametrize
@pytest.mark.parametrize(
    ("domain", "expected"),
    [
        ("domain", False),
        ("example.com", True),
        ("example", False),
        ("subdomain.example.com", True),
        ("www.example.com", True),
        ("example.com.", False),
        ("example@domain.com", False),
        ("123example.com", True),
        ("example-.com", False),
        ("my-domain.co.uk", True),
        ("test123.test-domain.com", True),
        ("example_domain.com", True),
        (".example12.com", False),
        ("example  12.com", False),
    ],
)
def test_domain(domain: str, expected: bool):
    assert yuko.domain(domain, False, False) == expected



import pytest

import yuko


@pytest.mark.parametrize(
    ("mac_address", "expected"),
    [
        ("01:23:45:67:ab:CD", True),
        ("01-23-45-67-ab-CD", True),
        ("01:2F:45:37:ab:CD", True),
        ("A1-2F-4E-68-ab-CD", True),
        ("00:1A:2B:3C:4D:5E", True),
        ("FF:FF:FF:FF:FF:FF", True),
        ("11:22:33:44:55:66", True),
        ("AA:BB:CC:DD:EE:FF", True),
        ("00:1A:2B:3C:4D:5E:6F", False),  # Invalid MAC address length
        ("00:1A:2B:3C:4D", False),  # Invalid MAC address length
        ("00:1A:2B:3C:4D:ZZ", False),  # Invalid hexadecimal digit
        ("00-00:-00-00-00", False),
        ("01:23-45:67-89:gh", False),
        ("", False),  # Empty MAC address
    ],
)
def test_mac_address(mac_address: str, expected: bool):
    assert yuko.mac_address(mac_address) == expected



import yuko
import pytest


# pytest parametrize
@pytest.mark.parametrize(
    "country_code, expected",
    [
        ("TR", True),
        ("AA", False),
        ("FR", True),
        ("001", False),
        ("422", True),
        ("TUR", True),
        ("BBB", False),
    ],
)
def test_country_code(country_code: str, expected: bool):
    assert yuko.country_code(country_code) == expected
